@@ -207,13 +207,13 @@ extern int _XlcResolveI18NPath(
 extern char *_XlcLocaleLibDirName(
      char*             /* dir_name */,
      size_t,	       /* dir_len */
-     char*             /* lc_name */
+     const char*       /* lc_name */
 );
 
 extern char *_XlcLocaleDirName(
      char*             /* dir_name */,
      size_t,	       /* dir_len */
-     char*             /* lc_name */
+     const char*       /* lc_name */
 );
 
 extern XPointer _XlcCreateLocaleDataBase(
@@ -232,12 +232,6 @@ extern void _XlcGetLocaleDataBase(
     int*		/* count */
 );
 
-#ifdef X_LOCALE
-extern char *
-_Xsetlocale(
-    int           category,
-    _Xconst char  *name);
-#else
 #ifdef __APPLE__
 extern char *
 _Xsetlocale(
@@ -247,7 +241,6 @@ _Xsetlocale(
 extern char *_XlcMapOSLocaleName(
     char *osname,
     char *siname);
-#endif
 
 extern int
 _Xmbstoutf8(
